@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import IO, Any, Dict, List, Type, Union, overload
+from typing import IO, Any, Dict, Mapping, Sequence, Type, Union, overload
 
 from botocore.client import BaseClient, ClientMeta
 from botocore.response import StreamingBody
@@ -51,7 +51,7 @@ from .type_defs import (
     UploadLayerPartResponseTypeDef,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import Literal
 else:
     from typing_extensions import Literal
@@ -63,7 +63,7 @@ __all__ = ("ECRPublicClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -97,7 +97,7 @@ class Exceptions:
 
 class ECRPublicClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/client.html)
     """
 
@@ -110,13 +110,13 @@ class ECRPublicClient(BaseClient):
         """
 
     def batch_check_layer_availability(
-        self, *, repositoryName: str, layerDigests: List[str], registryId: str = None
+        self, *, repositoryName: str, layerDigests: Sequence[str], registryId: str = ...
     ) -> BatchCheckLayerAvailabilityResponseTypeDef:
         """
         Checks the availability of one or more image layers within a repository in a
         public registry.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Client.batch_check_layer_availability)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Client.batch_check_layer_availability)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/client.html#batch_check_layer_availability)
         """
 
@@ -124,13 +124,13 @@ class ECRPublicClient(BaseClient):
         self,
         *,
         repositoryName: str,
-        imageIds: List["ImageIdentifierTypeDef"],
-        registryId: str = None
+        imageIds: Sequence["ImageIdentifierTypeDef"],
+        registryId: str = ...
     ) -> BatchDeleteImageResponseTypeDef:
         """
         Deletes a list of specified images within a repository in a public registry.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Client.batch_delete_image)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Client.batch_delete_image)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/client.html#batch_delete_image)
         """
 
@@ -138,18 +138,23 @@ class ECRPublicClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/client.html#can_paginate)
         """
 
     def complete_layer_upload(
-        self, *, repositoryName: str, uploadId: str, layerDigests: List[str], registryId: str = None
+        self,
+        *,
+        repositoryName: str,
+        uploadId: str,
+        layerDigests: Sequence[str],
+        registryId: str = ...
     ) -> CompleteLayerUploadResponseTypeDef:
         """
         Informs Amazon ECR that the image layer upload has completed for a specified
         public registry, repository name, and upload ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Client.complete_layer_upload)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Client.complete_layer_upload)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/client.html#complete_layer_upload)
         """
 
@@ -157,33 +162,33 @@ class ECRPublicClient(BaseClient):
         self,
         *,
         repositoryName: str,
-        catalogData: "RepositoryCatalogDataInputTypeDef" = None,
-        tags: List["TagTypeDef"] = None
+        catalogData: "RepositoryCatalogDataInputTypeDef" = ...,
+        tags: Sequence["TagTypeDef"] = ...
     ) -> CreateRepositoryResponseTypeDef:
         """
         Creates a repository in a public registry.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Client.create_repository)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Client.create_repository)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/client.html#create_repository)
         """
 
     def delete_repository(
-        self, *, repositoryName: str, registryId: str = None, force: bool = None
+        self, *, repositoryName: str, registryId: str = ..., force: bool = ...
     ) -> DeleteRepositoryResponseTypeDef:
         """
         Deletes a repository in a public registry.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Client.delete_repository)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Client.delete_repository)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/client.html#delete_repository)
         """
 
     def delete_repository_policy(
-        self, *, repositoryName: str, registryId: str = None
+        self, *, repositoryName: str, registryId: str = ...
     ) -> DeleteRepositoryPolicyResponseTypeDef:
         """
         Deletes the repository policy associated with the specified repository.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Client.delete_repository_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Client.delete_repository_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/client.html#delete_repository_policy)
         """
 
@@ -191,14 +196,14 @@ class ECRPublicClient(BaseClient):
         self,
         *,
         repositoryName: str,
-        registryId: str = None,
-        nextToken: str = None,
-        maxResults: int = None
+        registryId: str = ...,
+        nextToken: str = ...,
+        maxResults: int = ...
     ) -> DescribeImageTagsResponseTypeDef:
         """
         Returns the image tag details for a repository in a public registry.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Client.describe_image_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Client.describe_image_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/client.html#describe_image_tags)
         """
 
@@ -206,54 +211,54 @@ class ECRPublicClient(BaseClient):
         self,
         *,
         repositoryName: str,
-        registryId: str = None,
-        imageIds: List["ImageIdentifierTypeDef"] = None,
-        nextToken: str = None,
-        maxResults: int = None
+        registryId: str = ...,
+        imageIds: Sequence["ImageIdentifierTypeDef"] = ...,
+        nextToken: str = ...,
+        maxResults: int = ...
     ) -> DescribeImagesResponseTypeDef:
         """
         Returns metadata about the images in a repository in a public registry.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Client.describe_images)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Client.describe_images)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/client.html#describe_images)
         """
 
     def describe_registries(
-        self, *, nextToken: str = None, maxResults: int = None
+        self, *, nextToken: str = ..., maxResults: int = ...
     ) -> DescribeRegistriesResponseTypeDef:
         """
         Returns details for a public registry.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Client.describe_registries)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Client.describe_registries)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/client.html#describe_registries)
         """
 
     def describe_repositories(
         self,
         *,
-        registryId: str = None,
-        repositoryNames: List[str] = None,
-        nextToken: str = None,
-        maxResults: int = None
+        registryId: str = ...,
+        repositoryNames: Sequence[str] = ...,
+        nextToken: str = ...,
+        maxResults: int = ...
     ) -> DescribeRepositoriesResponseTypeDef:
         """
         Describes repositories in a public registry.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Client.describe_repositories)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Client.describe_repositories)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/client.html#describe_repositories)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/client.html#generate_presigned_url)
         """
 
@@ -261,7 +266,7 @@ class ECRPublicClient(BaseClient):
         """
         Retrieves an authorization token.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Client.get_authorization_token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Client.get_authorization_token)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/client.html#get_authorization_token)
         """
 
@@ -269,37 +274,37 @@ class ECRPublicClient(BaseClient):
         """
         Retrieves catalog metadata for a public registry.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Client.get_registry_catalog_data)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Client.get_registry_catalog_data)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/client.html#get_registry_catalog_data)
         """
 
     def get_repository_catalog_data(
-        self, *, repositoryName: str, registryId: str = None
+        self, *, repositoryName: str, registryId: str = ...
     ) -> GetRepositoryCatalogDataResponseTypeDef:
         """
         Retrieve catalog metadata for a repository in a public registry.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Client.get_repository_catalog_data)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Client.get_repository_catalog_data)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/client.html#get_repository_catalog_data)
         """
 
     def get_repository_policy(
-        self, *, repositoryName: str, registryId: str = None
+        self, *, repositoryName: str, registryId: str = ...
     ) -> GetRepositoryPolicyResponseTypeDef:
         """
         Retrieves the repository policy for the specified repository.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Client.get_repository_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Client.get_repository_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/client.html#get_repository_policy)
         """
 
     def initiate_layer_upload(
-        self, *, repositoryName: str, registryId: str = None
+        self, *, repositoryName: str, registryId: str = ...
     ) -> InitiateLayerUploadResponseTypeDef:
         """
         Notifies Amazon ECR that you intend to upload an image layer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Client.initiate_layer_upload)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Client.initiate_layer_upload)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/client.html#initiate_layer_upload)
         """
 
@@ -307,7 +312,7 @@ class ECRPublicClient(BaseClient):
         """
         List the tags for an Amazon ECR Public resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/client.html#list_tags_for_resource)
         """
 
@@ -316,25 +321,25 @@ class ECRPublicClient(BaseClient):
         *,
         repositoryName: str,
         imageManifest: str,
-        registryId: str = None,
-        imageManifestMediaType: str = None,
-        imageTag: str = None,
-        imageDigest: str = None
+        registryId: str = ...,
+        imageManifestMediaType: str = ...,
+        imageTag: str = ...,
+        imageDigest: str = ...
     ) -> PutImageResponseTypeDef:
         """
         Creates or updates the image manifest and tags associated with an image.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Client.put_image)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Client.put_image)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/client.html#put_image)
         """
 
     def put_registry_catalog_data(
-        self, *, displayName: str = None
+        self, *, displayName: str = ...
     ) -> PutRegistryCatalogDataResponseTypeDef:
         """
         Create or updates the catalog data for a public registry.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Client.put_registry_catalog_data)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Client.put_registry_catalog_data)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/client.html#put_registry_catalog_data)
         """
 
@@ -343,39 +348,39 @@ class ECRPublicClient(BaseClient):
         *,
         repositoryName: str,
         catalogData: "RepositoryCatalogDataInputTypeDef",
-        registryId: str = None
+        registryId: str = ...
     ) -> PutRepositoryCatalogDataResponseTypeDef:
         """
         Creates or updates the catalog data for a repository in a public registry.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Client.put_repository_catalog_data)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Client.put_repository_catalog_data)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/client.html#put_repository_catalog_data)
         """
 
     def set_repository_policy(
-        self, *, repositoryName: str, policyText: str, registryId: str = None, force: bool = None
+        self, *, repositoryName: str, policyText: str, registryId: str = ..., force: bool = ...
     ) -> SetRepositoryPolicyResponseTypeDef:
         """
         Applies a repository policy to the specified public repository to control access
         permissions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Client.set_repository_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Client.set_repository_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/client.html#set_repository_policy)
         """
 
-    def tag_resource(self, *, resourceArn: str, tags: List["TagTypeDef"]) -> Dict[str, Any]:
+    def tag_resource(self, *, resourceArn: str, tags: Sequence["TagTypeDef"]) -> Dict[str, Any]:
         """
         Associates the specified tags to a resource with the specified `resourceArn`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/client.html#tag_resource)
         """
 
-    def untag_resource(self, *, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
+    def untag_resource(self, *, resourceArn: str, tagKeys: Sequence[str]) -> Dict[str, Any]:
         """
         Deletes specified tags from a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/client.html#untag_resource)
         """
 
@@ -387,12 +392,12 @@ class ECRPublicClient(BaseClient):
         partFirstByte: int,
         partLastByte: int,
         layerPartBlob: Union[bytes, IO[bytes], StreamingBody],
-        registryId: str = None
+        registryId: str = ...
     ) -> UploadLayerPartResponseTypeDef:
         """
         Uploads an image layer part to Amazon ECR.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Client.upload_layer_part)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Client.upload_layer_part)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/client.html#upload_layer_part)
         """
 
@@ -401,14 +406,14 @@ class ECRPublicClient(BaseClient):
         self, operation_name: Literal["describe_image_tags"]
     ) -> DescribeImageTagsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Paginator.DescribeImageTags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Paginator.DescribeImageTags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/paginators.html#describeimagetagspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["describe_images"]) -> DescribeImagesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Paginator.DescribeImages)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Paginator.DescribeImages)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/paginators.html#describeimagespaginator)
         """
 
@@ -417,7 +422,7 @@ class ECRPublicClient(BaseClient):
         self, operation_name: Literal["describe_registries"]
     ) -> DescribeRegistriesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Paginator.DescribeRegistries)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Paginator.DescribeRegistries)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/paginators.html#describeregistriespaginator)
         """
 
@@ -426,6 +431,6 @@ class ECRPublicClient(BaseClient):
         self, operation_name: Literal["describe_repositories"]
     ) -> DescribeRepositoriesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/ecr-public.html#ECRPublic.Paginator.DescribeRepositories)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.8/reference/services/ecr-public.html#ECRPublic.Paginator.DescribeRepositories)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ecr_public/paginators.html#describerepositoriespaginator)
         """
