@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import IO, Any, Dict, List, Union
+from typing import IO, Any, Dict, List, Sequence, Union
 
 from botocore.response import StreamingBody
 
@@ -24,7 +24,7 @@ from .literals import (
     RegistryAliasStatusType,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
     from typing_extensions import TypedDict
@@ -106,7 +106,7 @@ _RequiredBatchCheckLayerAvailabilityRequestRequestTypeDef = TypedDict(
     "_RequiredBatchCheckLayerAvailabilityRequestRequestTypeDef",
     {
         "repositoryName": str,
-        "layerDigests": List[str],
+        "layerDigests": Sequence[str],
     },
 )
 _OptionalBatchCheckLayerAvailabilityRequestRequestTypeDef = TypedDict(
@@ -138,7 +138,7 @@ _RequiredBatchDeleteImageRequestRequestTypeDef = TypedDict(
     "_RequiredBatchDeleteImageRequestRequestTypeDef",
     {
         "repositoryName": str,
-        "imageIds": List["ImageIdentifierTypeDef"],
+        "imageIds": Sequence["ImageIdentifierTypeDef"],
     },
 )
 _OptionalBatchDeleteImageRequestRequestTypeDef = TypedDict(
@@ -170,7 +170,7 @@ _RequiredCompleteLayerUploadRequestRequestTypeDef = TypedDict(
     {
         "repositoryName": str,
         "uploadId": str,
-        "layerDigests": List[str],
+        "layerDigests": Sequence[str],
     },
 )
 _OptionalCompleteLayerUploadRequestRequestTypeDef = TypedDict(
@@ -210,7 +210,7 @@ _OptionalCreateRepositoryRequestRequestTypeDef = TypedDict(
     "_OptionalCreateRepositoryRequestRequestTypeDef",
     {
         "catalogData": "RepositoryCatalogDataInputTypeDef",
-        "tags": List["TagTypeDef"],
+        "tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -335,7 +335,7 @@ _OptionalDescribeImagesRequestRequestTypeDef = TypedDict(
     "_OptionalDescribeImagesRequestRequestTypeDef",
     {
         "registryId": str,
-        "imageIds": List["ImageIdentifierTypeDef"],
+        "imageIds": Sequence["ImageIdentifierTypeDef"],
         "nextToken": str,
         "maxResults": int,
     },
@@ -380,7 +380,7 @@ DescribeRepositoriesRequestRequestTypeDef = TypedDict(
     "DescribeRepositoriesRequestRequestTypeDef",
     {
         "registryId": str,
-        "repositoryNames": List[str],
+        "repositoryNames": Sequence[str],
         "nextToken": str,
         "maxResults": int,
     },
@@ -732,8 +732,8 @@ RepositoryCatalogDataInputTypeDef = TypedDict(
     "RepositoryCatalogDataInputTypeDef",
     {
         "description": str,
-        "architectures": List[str],
-        "operatingSystems": List[str],
+        "architectures": Sequence[str],
+        "operatingSystems": Sequence[str],
         "logoImageBlob": Union[bytes, IO[bytes], StreamingBody],
         "aboutText": str,
         "usageText": str,
@@ -816,7 +816,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "tags": List["TagTypeDef"],
+        "tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -833,7 +833,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "tagKeys": List[str],
+        "tagKeys": Sequence[str],
     },
 )
 
